@@ -1,7 +1,7 @@
 package Perinci::Access::Schemeless;
 
-our $DATE = '2014-12-02'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2014-12-03'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,7 +15,7 @@ use Perinci::Object;
 use Perinci::Sub::Normalize qw(normalize_function_metadata);
 use Perinci::Sub::Util qw(err);
 use Scalar::Util qw(blessed reftype);
-use SHARYANTO::Module::Path qw(module_path);
+use Module::Path::More qw(module_path);
 use SHARYANTO::Package::Util qw(package_exists);
 use Tie::Cache;
 use URI::Split qw(uri_split uri_join);
@@ -1012,7 +1012,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2014-12-02.
+This document describes version 0.76 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2014-12-03.
 
 =head1 DESCRIPTION
 
